@@ -29,9 +29,7 @@ nest. <- function(.df, ..., .names_sep = NULL) {
 }
 
 #' @export
-nest..data.frame <- function(.df, ..., .names_sep = NULL) {
-  .df <- as_tidytable(.df)
-
+nest..tidytable <- function(.df, ..., .names_sep = NULL) {
   if (!is.null(.names_sep)) vec_assert(.names_sep, character(), 1)
 
   dots <- enquos(...)
@@ -49,7 +47,7 @@ nest..data.frame <- function(.df, ..., .names_sep = NULL) {
   dots <- unname(dots)
 
   if (!is.null(.names_sep)) {
-    nest_cols <- select_dots_chr(.df, !!!dots)
+    nest_cols <- tidyselect_names(.df, !!!dots)
 
     new_names <- paste(.key, nest_cols, sep = .names_sep)
 
@@ -62,3 +60,9 @@ nest..data.frame <- function(.df, ..., .names_sep = NULL) {
 
   nest_by.(.df, -c(!!!dots), .key = .key)
 }
+
+#' @export
+nest..data.frame <- function(.df, ..., .names_sep = NULL) {
+  .df <- as_tidytable(.df)
+  nest.(.df, ..., .names_sep = .names_sep)
+}
